pub struct AuthCodeGrantFlow {
    pub client_id: String,
    pub client_secret: String,
}
The authorisation code flow is suitable for long-running applications (e.g. web and mobile apps) where the user grants permission only once.

If you’re using the authorisation code flow in any type of application where the client secret can’t be safely stored, then you should use the PKCE extension.

Fields

client_id: Stringclient_secret: String