Type Alias spotify_rs::client::AuthCodeClient

source ·
pub type AuthCodeClient<V = NoVerifier> = Client<UnAuthenticated, AuthCodeFlow, V>;
A client created using the Authorisation Code Flow.

Aliased Type

struct AuthCodeClient<V = NoVerifier> {
    pub auto_refresh: bool,
    /* private fields */
}

Fields

auto_refresh: bool

Dictates whether or not the client will request a new token when the current one is about the expire.

It will check if the token has expired in every request.