pub enum FeatureValue {
Float(f32),
Int(u32),
}Expand description
Represents the value of a feature. They can be either floats or values.
The value can be directly specified (e.g. 0, 100, 0.5, Mode::Major etc.), as this type
implements From for various type.
Note: You must use the right values yourself for each option. They can either take
integers from 0 - 100, floats from 0 - 1, or special types (like Mode)
In order to know what values each feature takes, you can use this page.
Example
let recommendations = recommendations(Seed::artists(&["59XQUEHhy5830QsAsmhe2M"]))
.features(&[
Feature::min(FeatureKind::Energy, 0.5),
Feature::max(FeatureKind::Popularity, 64),
Feature::target(FeatureKind::Mode, Mode::Major),
])
.get(spotify)
.await?;Variants