AudioAnalysis

Struct AudioAnalysis 

pub struct AudioAnalysis {
    pub meta: Meta,
    pub track: TrackAnalysis,
    pub bars: Vec<Bar>,
    pub beats: Vec<Beat>,
    pub sections: Vec<Section>,
    pub segments: Vec<Segment>,
    pub tatums: Vec<Tatum>,
}
Audio analysis for a track.

Fields

meta: Metatrack: TrackAnalysisbars: Vec<Bar>

The time intervals of the measures throughout the track. A measure (or bar) is a segment of time defined by a specific number of beats.

beats: Vec<Beat>

The timing intervals of beats throughout the track. A beat is the fundamental time unit of a piece of music; for instance, each tick of a metronome. Beats are usually multiples of tatums.

sections: Vec<Section>

Sections are defined by significant changes in rhythm or timbre, such as the chorus, verse, bridge, guitar solo, etc.

Each section has its own descriptions of tempo, key, mode, time signature, and loudness.

segments: Vec<Segment>

Each segment contains a relatively consistent sound throughout its duration.

tatums: Vec<Tatum>

A tatum represents the smallest regular pulse that a listener naturally infers from the timing of perceived musical events (segments).