pub struct Beat {
pub start: f32,
pub duration: f32,
pub confidence: f32,
}Expand description
A beat is the fundamental time unit of a piece of music; for instance, each tick of a metronome. Beats are usually multiples of tatums.
Fields
start: f32The starting point, in seconds, of the time interval.
duration: f32The duration, in seconds, of the time interval.
confidence: f32A value ranging betweeen 0.0 - 1.0 that indicates the confidence of
the interval.