pub struct Meta {
pub analyzer_version: String,
pub platform: String,
pub detailed_status: String,
pub status_code: AnalysisStatusCode,
pub timestamp: u64,
pub analysis_time: f32,
pub input_process: String,
}Fields
analyzer_version: StringThe version of the analyser used to analyse the track.
platform: StringThe platform used to read the track’s audio data (e.g. Linux).
detailed_status: StringA status code for the track. If analysis data is missing, the status code may explain why.
status_code: AnalysisStatusCodeThe return code of the analyser process.
timestamp: u64The Unix timestamp at which the track was analysed.
analysis_time: f32The amount of time taken to analyse the track.
input_process: StringThe method used to read the track’s audio data.