TrackAnalysis

Struct TrackAnalysis 

pub struct TrackAnalysis {
Show 26 fields pub num_samples: u32, pub duration: f32, pub sample_md5: String, pub offset_seconds: u32, pub window_seconds: u32, pub analysis_sample_rate: u32, pub analysis_channels: u32, pub end_of_fade_in: f32, pub start_of_fade_out: f32, pub loudness: f32, pub tempo: f32, pub tempo_confidence: f32, pub time_signature: u32, pub time_signature_confidence: f32, pub key: i32, pub key_confidence: f32, pub mode: Mode, pub mode_confidence: f32, pub codestring: String, pub code_version: f32, pub echoprint_string: String, pub echoprint_version: f32, pub synchstring: String, pub synch_version: f32, pub rhythmstring: String, pub rhythm_version: f32,
}

Fields

num_samples: u32

The number of audio samples from the track that were analysed.

duration: f32

The length of the track in seconds.

sample_md5: String

This field will always contain an empty string.

offset_seconds: u32

An offset to the start of the segment of the track that awas analysed. As the entire track is analysed, this should be 0.

window_seconds: u32

The length of the segment of the track that was analysed, if only a subset was. As the entire track is analysed, this should be 0.

analysis_sample_rate: u32

The sample rate used to decode and analyse the track. May vary from the track’s sample rate on Spotify.

analysis_channels: u32

The number of channels used in the analysis. If the value is 1, all the channels were combined to mono before analysis.

end_of_fade_in: f32

The time, in seconds, when the track’s fade-in ends. If the track has no fade-in, the value is 0.

start_of_fade_out: f32

The time, in seconds, when the track’s fade-out begins. If the track has no fade-out, this will match the track’s length.

loudness: f32

The average loudness of the track in decibels (dB). Loudness values are averaged across the entire track and are useful for comparing relative loudness of tracks.

Values typically range between -60 and 0 dB.

tempo: f32

The estimated pace of the track in beats per minute (BPM).

tempo_confidence: f32

A value ranging between 0.0 - 1.0 that indicates the confidence of the tempo.

time_signature: u32

An estimated notation of how many beats are in each measure.

Values range between 3 - 7, indicating time signatures ranging between 3/4 - 7/4.

time_signature_confidence: f32

A value ranging between 0.0 - 1.0 that indicates the confidence of the time_signature.

key: i32

A value ranging between -1 - 11 that denotes musical key of the track, represented by integers mapping to pitches using standard [Pitch Class notation] (https://en.wikipedia.org/wiki/Pitch_class).

If no key is detected, the value is -1.

key_confidence: f32

A value ranging between 0.0 - 1.0 that indicates the confidence of the key.

mode: Mode

Indicates the modality (major or minor) of a track.

mode_confidence: f32

A value ranging between 0.0 - 1.0 that indicates the confidence of the mode.

codestring: String

An ENMPF codestring for the track.

code_version: f32

The version for the ENMPF used in the codestring.

echoprint_string: String

An EchoPrint codestring for the track.

echoprint_version: f32

The version for the EchoPrint format used in the echoprintstring.

synchstring: String

A SynchString for the track.

synch_version: f32

The version for the Synchstring used in the synchstring.

rhythmstring: String

A Rhythmstring for the track. Its format is similar to that of the synchstring.

rhythm_version: f32

The version for the Rhythmstring used in the rhythmstring.