pub struct SimplifiedChapter {Show 20 fields
pub audio_preview_url: Option<String>,
pub available_markets: Vec<String>,
pub chapter_number: u32,
pub description: String,
pub html_description: String,
pub duration_ms: u32,
pub explicit: bool,
pub external_urls: ExternalUrls,
pub href: String,
pub id: String,
pub images: Vec<Image>,
pub is_playable: Option<bool>,
pub languages: Vec<String>,
pub name: String,
pub release_date: String,
pub release_date_precision: DatePrecision,
pub resume_point: Option<ResumePoint>,
pub type: String,
pub uri: String,
pub restrictions: Option<Restriction>,
}Expand description
A simplified chapter, missing some details, that is usually obtained
through endpoints not specific to chapters. The href field may be
used to get a full chapter.
Fields
audio_preview_url: Option<String>The URL for a 30 second MP3 preview of the chapter.
Note: This attribute has been deprecated by Spotify. It continues to work for applications already using the extended mode in the API.
You can read more about this here.
available_markets: Vec<String>The ISO 3166-1 alpha-2 codes for the markets in which the chapter is available.
chapter_number: u32The number of the chapter in the audiobook it belongs to.
description: StringA text description of the chapter.
html_description: StringA description of the chapter that may contain HTML tags.
duration_ms: u32The duration of the chapter in miliseconds.
explicit: boolWhether or not the chapter contains explicit content.
Note: false can also mean unknown.
external_urls: ExternalUrlsKnown external URLs for the chapter.
href: StringA link to the Spotify Web API endpoint providing full details of the chapter.
id: StringThe Spotify ID for the chapter.
images: Vec<Image>The cover art for the chapter in various sizes, with the widest first.
is_playable: Option<bool>Indicates whether or not the chapter is playable in the current market.
languages: Vec<String>A list of ISO 639 codes for the languages spoken in the chapter.
name: StringThe name of the chapter.
release_date: StringThe date the chapter was first released.
release_date_precision: DatePrecisionThe precision with which the release_date field is known.
resume_point: Option<ResumePoint>The user’s latest position in the chapter.
Note: this field is only available if the user is authorised with the user-read-playback-position scope.
type: StringThe object type. Allowed values: chapter.
uri: StringThe Spotify URI for the chapter.
restrictions: Option<Restriction>Included in the response when a content restriction is applied. Included in the response when a content restriction is applied.