#[non_exhaustive]pub enum RestrictionReason {
Market,
Product,
Explicit,
Unknown,
}Expand description
The reason for restriction on content.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Market
A restriction set because of the market of a user.
Product
A restriction set because of the user’s subscription type.
Explicit
A restriction set because the content is explicit, and the user settings are set so that explicit conent can’t be played.
Unknown
Any other type of restriction, as more may be added in the future.