pub enum RepeatState {
Off,
Track,
Context,
}Expand description
The repeat state of the playback.
Variants
Off
After the current item ends, it won’t repeat.
Track
After the current item ends, the item will be repeated.
Context
After the current item ends, the context of the item will be repeated (e.g. the playlist).