Struct spotify_rs::model::player::Actions
source · pub struct Actions {
pub disallows: Disallows,
}Expand description
Allows to update the user interface based on which playback actions are available within the current context.
Fields
disallows: DisallowsTrait Implementations
sourceimpl<'de> Deserialize<'de> for Actions
impl<'de> Deserialize<'de> for Actions
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more