pub struct PlaybackState {
pub device: Option<Device>,
pub repeat_state: Option<RepeatState>,
pub shuffle_state: Option<bool>,
pub context: Option<Context>,
pub timestamp: u64,
pub progress_ms: Option<u32>,
pub is_playing: bool,
pub item: Option<PlayableItem>,
pub currently_playing_type: CurrentlyPlayingType,
pub actions: Actions,
}Expand description
The current user’s playback state.
Fields
device: Option<Device>The currently active device.
repeat_state: Option<RepeatState>The repeat state.
shuffle_state: Option<bool>Whether or not shuffle is enabled.
context: Option<Context>The context the item is being played from. (e.g. arist, playlist, album or show.
timestamp: u64A Unix timestamp of when the playback state was last changed.
progress_ms: Option<u32>The playback position in miliseconds.
is_playing: boolWhether or not the user is playing something.
item: Option<PlayableItem>The currently playing item - a track or episode.
currently_playing_type: CurrentlyPlayingTypeThe type of the currently playing item. It may have more variants than item.
actions: ActionsAllows to update the user interface based on which playback actions are currently available.