pub struct TrackReference {
pub href: String,
pub total: u32,
}Expand description
Contains the link where the full details of a playlist’s tracks can be found, as well as the number of the tracks in the playlist.
Fields
href: StringA link to the Spotify Web API endpoint providing full details of the playlist’s tracks.
total: u32The number of tracks in the playlist.