pub struct SimplifiedEpisode {Show 19 fields
pub audio_preview_url: Option<String>,
pub description: String,
pub html_description: String,
pub duration_ms: u32,
pub explicit: bool,
pub external_urls: ExternalUrls,
pub href: String,
pub id: String,
pub images: Vec<Image>,
pub is_externally_hosted: bool,
pub is_playable: bool,
pub languages: Vec<String>,
pub name: String,
pub release_date: String,
pub release_date_precision: DatePrecision,
pub resume_point: Option<ResumePoint>,
pub type: String,
pub uri: String,
pub restrictions: Option<Restriction>,
}Expand description
A simplified episode, missing some details, that is usually obtained
through endpoints not specific to episodes. The href field may be
used to get a full episode.
Fields
audio_preview_url: Option<String>The URL for a 30 second MP3 preview of the chapter.
Note: This attribute has been deprecated by Spotify. It continues to work for applications already using the extended mode in the API.
You can read more about this here.
description: StringA text description of the episode.
html_description: StringA description of the episode that may contain HTML tags.
duration_ms: u32The duration of the episode in miliseconds.
explicit: boolWhether or not the episode contains explicit content.
Note: false can also mean unknown.
external_urls: ExternalUrlsKnown external URLs for the episode.
href: StringA link to the Spotify Web API endpoint providing full details of the episode.
id: StringThe Spotify ID for the episode.
images: Vec<Image>The cover art for the episode in various sizes, with the widest first.
is_externally_hosted: boolWhether or not the episode is hosted outside of Spotify’s CDN.
is_playable: boolIndicates whether or not the episode is playable in the current market.
languages: Vec<String>A list of ISO 639 codes for the languages spoken in the episode.
name: StringThe name of the episode.
release_date: StringThe date the episode was first released.
release_date_precision: DatePrecisionThe precision with which the release_date field is known.
resume_point: Option<ResumePoint>The user’s latest position in the episode.
Note: this field is only available if the user is authorised with the user-read-playback-position scope.
type: StringThe object type. Allowed values: episode.
uri: StringThe Spotify URI for the episode.
restrictions: Option<Restriction>Included in the response when a content restriction is applied. Included in the response when a content restriction is applied.