Page

Struct Page 

pub struct Page<T: Clone> {
    pub href: String,
    pub limit: u32,
    pub next: Option<String>,
    pub offset: u32,
    pub previous: Option<String>,
    pub total: u32,
    pub items: Vec<Option<T>>,
}
This represents a page of items, which is a segment of data returned by the Spotify API.

To get the rest of the data, the fields of this struct, or, preferably, some methods can be used to get the next or previous page, or the remaining or all items.

Fields

href: String

The URL to the API endpoint returning this page.

limit: u32

The maximum amount of items in the response.

next: Option<String>

The URL to the next page. For pagination, see get_next.

offset: u32

The offset of the returned items.

previous: Option<String>

The URL to the previous page. For pagination, see get_previous.

total: u32

The amount of returned items.

items: Vec<Option<T>>

A list of the items, which includes null values. To get only the Some values, use filtered_items.

Implementations

Source

impl<T: Clone + DeserializeOwned> Page<T>

pub fn filtered_items(&self) -> Vec<T>

Get a list of only the Some values from a Page’s items.

pub async fn get_next( &self, spotify: &Client<Token, impl AuthFlow>, ) -> Result<Self>

Get the next page.

If there is no next page, this will return an Error::NoRemainingPages.

pub async fn get_previous( &self, spotify: &Client<Token, impl AuthFlow>, ) -> Result<Self>

Get the previous page.

If there is no previous page, this will return an Error::NoRemainingPages.

pub async fn get_remaining( self, spotify: &Client<Token, impl AuthFlow>, ) -> Result<Vec<Option<T>>>

Get the items of all the remaining pages - that is, all the pages found after the current one.

pub async fn get_all( self, spotify: &Client<Token, impl AuthFlow>, ) -> Result<Vec<Option<T>>>

Get the items of all of the pages - that is, all the pages found both before and after the current one.