pub struct PrivateUser {
pub country: String,
pub display_name: Option<String>,
pub email: String,
pub explicit_content: Option<ExplicitContent>,
pub external_urls: ExternalUrls,
pub followers: Followers,
pub href: String,
pub id: String,
pub images: Vec<Image>,
pub product: Option<String>,
pub type: String,
pub uri: String,
}Expand description
Information about the current user, which can only be obtained when authorised by the user.
Fields
country: StringAn ISO 3661-1 alpha-2 code that represents the user’s country, as set in the user’s account.
Note: this field is only available if the user is authorised with the
user-read-private scope.
display_name: Option<String>The name that is displayed on the user’s profile.
email: StringThe user’s email address.
Note: this email address is unverified, meaning that there is no proof
that it actually belongs to the user; this field is only available if the
user is authorised with the user-read-email scope.
explicit_content: Option<ExplicitContent>The user’s explicit content settings.
Note: This field is only available if the user is authorised with the
user-read-private scope.
external_urls: ExternalUrlsKnown external URLs for the user.
followers: FollowersThe followers of a user.
href: StringA link to the Spotify Web API endpoint providing full details of the user.
id: StringThe Spotify ID for the user.
images: Vec<Image>The cover art for the user in various sizes, with the widest first.
product: Option<String>The user’s Spotify subscription tier. The value open can be considered
the same as free.
Note: This field is only available if the user is authorised with the
user-read-private scope.
type: StringThe object type. Allowed values: user.
uri: StringThe Spotify URI for the user.