Struct spotify_rs::auth::AuthCodeGrantFlow
source · pub struct AuthCodeGrantFlow {
pub client_id: String,
pub client_secret: String,
}Expand description
The authorisation code flow is suitable for long-running applications (e.g. web and mobile apps) where the user grants permission only once.
If you’re using the authorisation code flow in any type of application where the client secret can’t be safely stored, then you should use the PKCE extension.
Fields
client_id: Stringclient_secret: StringTrait Implementations
sourceimpl AuthFlow for AuthCodeGrantFlow
impl AuthFlow for AuthCodeGrantFlow
sourceimpl Clone for AuthCodeGrantFlow
impl Clone for AuthCodeGrantFlow
sourcefn clone(&self) -> AuthCodeGrantFlow
fn clone(&self) -> AuthCodeGrantFlow
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AuthCodeGrantFlow
impl Debug for AuthCodeGrantFlow
impl Authorised for AuthCodeGrantFlow