Type Alias spotify_rs::client::AuthCodePkceClient
source · pub type AuthCodePkceClient<V = NoVerifier> = Client<UnAuthenticated, AuthCodePkceFlow, V>;Expand description
A client created using the Authorisation Code with PKCE Flow.
Aliased Type
struct AuthCodePkceClient<V = NoVerifier> {
pub auto_refresh: bool,
/* private fields */
}Fields
auto_refresh: boolDictates whether or not the client will request a new token when the current one is about the expire.
It will check if the token has expired in every request.