Type Alias spotify_rs::client::ClientCredsClient

source ·
pub type ClientCredsClient<V = NoVerifier> = Client<UnAuthenticated, ClientCredsFlow, V>;
A client created using the Client Credentials Flow.

Aliased Type

struct ClientCredsClient<V = NoVerifier> {
    pub auto_refresh: bool,
    /* private fields */
}

Fields

auto_refresh: bool

Dictates whether or not the client will request a new token when the current one is about the expire.

It will check if the token has expired in every request.