Enum spotify_rs::Error
source · pub enum Error {
Authentication {
kind: Kind,
description: String,
},
ExpiredToken,
Http(String),
InvalidStateParameter,
NotAuthenticated,
RefreshUnavailable,
Spotify {
status: u16,
message: String,
},
}Expand description
An error returned by the client in a custom Result.
Variants
Authentication
Error that occured during authentication.
ExpiredToken
The token has expired and auto-refresh is turned off.
Http(String)
HTTP error returned from the underlying HTTP client.
InvalidStateParameter
The (CSRF) state parameter supplied is not the same as the one initially generated and sent to the server.
Learn more about CSRF here.
NotAuthenticated
The client has not yet been authenticated.
The access token has expired and refreshing it is not possible in the current authorisation flow.
Spotify
An error returned from Spotify.