pub struct AudioFeatures {Show 18 fields
pub acousticness: f32,
pub analysis_url: String,
pub danceability: f32,
pub duration_ms: u32,
pub energy: f32,
pub id: String,
pub instrumentalness: f32,
pub key: i32,
pub liveness: f32,
pub loudness: f32,
pub mode: Mode,
pub speechiness: f32,
pub tempo: f32,
pub time_signature: u32,
pub track_href: String,
pub type: String,
pub uri: String,
pub valence: f32,
}Expand description
Audio features for a track.
Fields
acousticness: f32A measure of confidence from 0.0 to 1.0 indicating whether the track is acoustic.
A score of 1.0 implies high certainty that the track is acoustic.
analysis_url: StringA URL to access the full audio analysis of the track.
danceability: f32A measure between 0.0 - 1.0 that describes how suitable a track is for
dancing based on various musical factors like tempo, rhythm stability,
beat strength, and overall regularity.
duration_ms: u32The duration of the track in miliseconds.
energy: f32A score between 0.0 - 1.0 that represents the intensity and activity
level of a track.
Energetic tracks feel fast, loud, and lively. For instance, death metal scores high in energy, while a Bach prelude scores low.
Features contributing to this include dynamic range, perceived loudness, timbre, onset rate, and overall entropy.
id: StringThe Spotify ID for the track.
instrumentalness: f32A value between 0.0 - 1.0 that estimates the likelihood of a track being
instrumental (no vocals).
‘Ooh’ and ‘aah’ sounds are considered instrumental. Rap or spoken word tracks are considered vocal.
Values above 0.5 suggest instrumental tracks, but confidence is higher
as the value nears 1.0.
key: i32A value ranging between -1 - 11 that denotes musical key of the track,
represented by integers mapping to pitches using standard
[Pitch Class notation] (https://en.wikipedia.org/wiki/Pitch_class).
If no key is detected, the value is -1.
liveness: f32A value ranging between 0.0 and 1.0 that measures the likelihood
of the presence of an audience in the recording.
A value above 0.8 strongly suggests that the track is live.
loudness: f32The average loudness of the track in decibels (dB). Loudness values are averaged across the entire track and are useful for comparing relative loudness of tracks.
Values typically range between -60 and 0 dB.
mode: ModeIndicates the modality (major or minor) of the track.
speechiness: f32A value between 0.0 - 1.0 that detects the presence of spoken words in
a track. A value closer to 1.0 indicates more speech-like content.
Values below 0.33 most likely represent music.
Values between 0.33 - 0.66 describe tracks that may contain both music and speech,
either in sections or layered.
Values above 0.66 most likely represent tracks that consist entirely of
spoken words, like podcasts, audiobooks etc.
tempo: f32The estimated pace of the track in beats per minute (BPM).
time_signature: u32An estimated notation of how many beats are in each measure.
Values range between 3 - 7, indicating time signatures ranging
between 3/4 - 7/4.
track_href: StringA link to the Spotify Web API endpoint providing full details of the track.
type: StringThe object type. Allowed values: audio_features.
uri: StringThe Spotify URI for the track.
valence: f32A measure from 0.0 to 1.0 describing the musical positiveness
conveyed by a track.
High valence tracks sound more positive (e.g. happy, cheerful), while low valence tracks sound more negative (e.g. sad, depressed, angry).