Struct spotify_rs::model::audio::AudioFeatures
source · pub struct AudioFeatures {Show 18 fields
pub acousticness: f32,
pub analysis_url: String,
pub danceability: f32,
pub duration_ms: u32,
pub energy: f32,
pub id: String,
pub instrumentalness: f32,
pub key: i32,
pub liveness: f32,
pub loudness: f32,
pub mode: Mode,
pub speechiness: f32,
pub tempo: f32,
pub time_signature: u32,
pub track_href: String,
pub type: String,
pub uri: String,
pub valence: f32,
}Fields
acousticness: f32analysis_url: Stringdanceability: f32duration_ms: u32energy: f32id: Stringinstrumentalness: f32key: i32The key the track is in. Integers map to pitches using standard Pitch Class notation. E.g. 0 = C, 1 = C♯/D♭, 2 = D, and so on. If no key was detected, the value is -1.
liveness: f32loudness: f32mode: Modespeechiness: f32tempo: f32time_signature: u32track_href: Stringtype: Stringuri: Stringvalence: f32Trait Implementations
sourceimpl Clone for AudioFeatures
impl Clone for AudioFeatures
sourcefn clone(&self) -> AudioFeatures
fn clone(&self) -> AudioFeatures
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AudioFeatures
impl Debug for AudioFeatures
sourceimpl<'de> Deserialize<'de> for AudioFeatures
impl<'de> Deserialize<'de> for AudioFeatures
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more