pub struct Section {
pub start: f32,
pub duration: f32,
pub confidence: f32,
pub loudness: f32,
pub tempo: f32,
pub tempo_confidence: f32,
pub key: i32,
pub key_confidence: f32,
pub mode: Mode,
pub mode_confidence: f32,
pub time_signature: u32,
pub time_signature_confidence: f32,
}Expand description
A section is defined by significant changes in rhythm or timbre, such as the chorus, verse, bridge, guitar solo, etc.
Fields
start: f32The starting point, in seconds, of the section.
duration: f32The duration, in seconds, of the section.
confidence: f32A value ranging betweeen 0.0 - 1.0 that indicates the confidence of
the section’s “designation”.
loudness: f32The average loudness of the section in decibels (dB). Loudness values are useful for comparing relative loudness of sections.
tempo: f32The estimated pace of the section in beats per minute (BPM).
tempo_confidence: f32A value ranging betweeen 0.0 - 1.0 that indicates the confidence of
the tempo.
key: i32A value ranging between -1 - 11 that denotes musical key of the section,
represented by integers mapping to pitches using standard
[Pitch Class notation] (https://en.wikipedia.org/wiki/Pitch_class).
If no key is detected, the value is -1.
key_confidence: f32A value ranging betweeen 0.0 - 1.0 that indicates the confidence of
the key.
mode: ModeIndicates the modality (major or minor) of the section.
mode_confidence: f32A value ranging betweeen 0.0 - 1.0 that indicates the confidence of
the mode.
time_signature: u32An estimated notation of how many beats are in each measure.
Values range between 3 - 7, indicating time signatures ranging
between 3/4 - 7/4.
time_signature_confidence: f32A value ranging betweeen 0.0 - 1.0 that indicates the confidence of
the time signature.