pub struct SimplifiedShow {Show 17 fields
pub available_markets: Vec<String>,
pub copyrights: Vec<String>,
pub description: String,
pub html_description: String,
pub explicit: bool,
pub external_urls: ExternalUrls,
pub href: String,
pub id: String,
pub images: Vec<Image>,
pub is_externally_hosted: Option<bool>,
pub languages: Vec<String>,
pub media_type: String,
pub name: String,
pub publisher: String,
pub type: String,
pub uri: String,
pub total_episodes: u32,
}Expand description
A simplified show, missing some details, that is usually obtained
through endpoints not specific to shows. The href field may be
used to get a full show.
Fields
available_markets: Vec<String>The ISO 3166-1 alpha-2 codes for the markets in which the show is available.
copyrights: Vec<String>The copyright statements of the show.
description: StringA text description of the show.
html_description: StringA description of the show that may contain HTML tags.
explicit: boolWhether or not the show contains explicit content.
Note: false can also mean unknown.
external_urls: ExternalUrlsKnown external URLs for the show.
href: StringA link to the Spotify Web API endpoint providing full details of the show.
id: StringThe Spotify ID for the show.
images: Vec<Image>The cover art for the show in various sizes, with the widest first.
is_externally_hosted: Option<bool>Whether or not all of the show’s episodes are hosted outside of Spotify’s CDN.
languages: Vec<String>A list of ISO 639 codes for the languages spoken in the show.
media_type: StringThe type of the media of the show.
name: StringThe name of the show.
publisher: StringThe publisher of the show.
type: StringThe object type. Allowed values: show.
uri: StringThe Spotify URI for the show.
total_episodes: u32The amount of episodes the show contains.