pub struct Page<T: Clone> {
pub href: String,
pub limit: u32,
pub next: Option<String>,
pub offset: u32,
pub previous: Option<String>,
pub total: u32,
pub items: Vec<Option<T>>,
}Expand description
Fields
href: StringThe URL to the API endpoint returning this page.
limit: u32The maximum amount of items in the response.
next: Option<String>The URL to the next page.
For pagination, see get_next.
offset: u32The offset of the returned items.
previous: Option<String>The URL to the previous page.
For pagination, see get_previous.
total: u32The amount of returned items.
items: Vec<Option<T>>A list of the items, which includes null values.
To get only the Some values, use filtered_items.
Implementations
Sourceimpl<T: Clone + DeserializeOwned> Page<T>
impl<T: Clone + DeserializeOwned> Page<T>
Sourcepub fn filtered_items(&self) -> Vec<T>
pub fn filtered_items(&self) -> Vec<T>
Get a list of only the Some values from a Page’s items.
Sourcepub async fn get_next(
&self,
spotify: &Client<Token, impl AuthFlow>,
) -> Result<Self>
pub async fn get_next( &self, spotify: &Client<Token, impl AuthFlow>, ) -> Result<Self>
Get the next page.
If there is no next page, this will return an
Error::NoRemainingPages.
Sourcepub async fn get_previous(
&self,
spotify: &Client<Token, impl AuthFlow>,
) -> Result<Self>
pub async fn get_previous( &self, spotify: &Client<Token, impl AuthFlow>, ) -> Result<Self>
Get the previous page.
If there is no previous page, this will return an
Error::NoRemainingPages.