Struct spotify_rs::model::user::PrivateUser
source · pub struct PrivateUser {
pub country: String,
pub display_name: Option<String>,
pub email: String,
pub explicit_content: Option<ExplicitContent>,
pub external_urls: ExternalUrls,
pub followers: Followers,
pub href: String,
pub id: String,
pub images: Vec<Image>,
pub product: Option<String>,
pub type: String,
pub uri: String,
}Fields
country: Stringdisplay_name: Option<String>email: Stringexplicit_content: Option<ExplicitContent>The user’s explicit content settings. This field is only available when the current user has granted access to the user-read-private scope.
external_urls: ExternalUrlsfollowers: Followershref: Stringid: Stringimages: Vec<Image>product: Option<String>The user’s Spotify subscription level: “premium”, “free”, etc. (The subscription level “open” can be considered the same as “free”.) This field is only available when the current user has granted access to the user-read-private scope.
type: Stringuri: StringTrait Implementations
sourceimpl Clone for PrivateUser
impl Clone for PrivateUser
sourcefn clone(&self) -> PrivateUser
fn clone(&self) -> PrivateUser
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for PrivateUser
impl Debug for PrivateUser
sourceimpl<'de> Deserialize<'de> for PrivateUser
impl<'de> Deserialize<'de> for PrivateUser
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more